@@ -1,5 +1,5 @@
 <?php
-/* $Id: bookmark.lib.php,v 2.12 2005/03/07 21:30:59 lem9 Exp $ */
+/* $Id: bookmark.lib.php,v 2.16 2006/01/17 17:02:30 cybot_tm Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 /**
@@ -49,18 +49,18 @@ function PMA_getBookmarksParam()
  */
 function PMA_listBookmarks($db, $cfgBookmark)
 {
-    global $dbh;
+    global $controllink;
 
     $query  = 'SELECT label, id FROM '. PMA_backquote($cfgBookmark['db']) . '.' . PMA_backquote($cfgBookmark['table'])
             . ' WHERE dbase = \'' . PMA_sqlAddslashes($db) . '\''
             . ' AND (user = \'' . PMA_sqlAddslashes($cfgBookmark['user']) . '\''
             . '      OR user = \'\')'
             . ' ORDER BY label';
-    $result = PMA_DBI_query($query, $dbh, PMA_DBI_QUERY_STORE);
+    $result = PMA_DBI_query($query, $controllink, PMA_DBI_QUERY_STORE);
 
     // There are some bookmarks -> store them
     // use the unique id as the key
-    if ($result > 0 && PMA_DBI_num_rows($result) > 0) {
+    if ($result && PMA_DBI_num_rows($result) > 0) {
         while ($row = PMA_DBI_fetch_row($result)) {
             $bookmark_list[$row[1]] = $row[0];
         } // end while
@@ -90,7 +90,7 @@ function PMA_listBookmarks($db, $cfgBookmark)
  */
 function PMA_queryBookmarks($db, $cfgBookmark, $id, $id_field = 'id', $action_bookmark_all = FALSE)
 {
-    global $dbh;
+    global $controllink;
 
     if (empty($cfgBookmark['db']) || empty($cfgBookmark['table'])) {
         return '';
@@ -101,8 +101,10 @@ function PMA_queryBookmarks($db, $cfgBookmark, $id, $id_field = 'id', $action_bo
                     . ($action_bookmark_all? '' : ' AND (user = \'' . PMA_sqlAddslashes($cfgBookmark['user']) . '\''
                     . '      OR user = \'\')' )
                     . ' AND ' . PMA_backquote($id_field) . ' = ' . $id;
-    $result = PMA_DBI_try_query($query, $dbh);
-    if (!$result) return FALSE;
+    $result = PMA_DBI_try_query($query, $controllink);
+    if (!$result) {
+        return FALSE;
+    }
     list($bookmark_query) = PMA_DBI_fetch_row($result) or array(FALSE);
 
     return $bookmark_query;
@@ -124,7 +126,7 @@ function PMA_queryBookmarks($db, $cfgBookmark, $id, $id_field = 'id', $action_bo
  */
 function &PMA_queryDBBookmarks($db, $cfgBookmark, &$table_array)
 {
-    global $dbh;
+    global $controllink;
     $bookmarks = array();
 
     if (empty($cfgBookmark['db']) || empty($cfgBookmark['table'])) {
@@ -132,15 +134,17 @@ function &PMA_queryDBBookmarks($db, $cfgBookmark, &$table_array)
     }
 
     $search_for = array();
-    foreach($table_array AS $table => $table_sortkey) {
+    foreach ($table_array AS $table => $table_sortkey) {
         $search_for[] = "'" . PMA_sqlAddslashes($table) . "'";
     }
 
     $query          = 'SELECT label, query FROM ' . PMA_backquote($cfgBookmark['db']) . '.' . PMA_backquote($cfgBookmark['table'])
                     . ' WHERE dbase = \'' . PMA_sqlAddslashes($db) . '\''
                     . (count($search_for) > 0 ? ' AND label IN (' . implode(', ', $search_for) . ')' : '');
-    $result = PMA_DBI_try_query($query, $dbh, PMA_DBI_QUERY_STORE);
-    if (!$result || PMA_DBI_num_rows($result) < 1) return $bookmarks;
+    $result = PMA_DBI_try_query($query, $controllink, PMA_DBI_QUERY_STORE);
+    if (!$result || PMA_DBI_num_rows($result) < 1) {
+        return $bookmarks;
+    }
     while ($row = PMA_DBI_fetch_assoc($result)) {
         $bookmarks[$row['label']] = $row['query'];
     }
@@ -163,11 +167,11 @@ function &PMA_queryDBBookmarks($db, $cfgBookmark, &$table_array)
  */
 function PMA_addBookmarks($fields, $cfgBookmark, $all_users = false)
 {
-    global $dbh;
+    global $controllink;
 
     $query = 'INSERT INTO ' . PMA_backquote($cfgBookmark['db']) . '.' . PMA_backquote($cfgBookmark['table'])
-           . ' (id, dbase, user, query, label) VALUES (\'\', \'' . PMA_sqlAddslashes($fields['dbase']) . '\', \'' . ($all_users ? '' : PMA_sqlAddslashes($fields['user'])) . '\', \'' . PMA_sqlAddslashes(urldecode($fields['query'])) . '\', \'' . PMA_sqlAddslashes($fields['label']) . '\')';
-    $result   = PMA_DBI_query($query, $dbh);
+           . ' (id, dbase, user, query, label) VALUES (NULL, \'' . PMA_sqlAddslashes($fields['dbase']) . '\', \'' . ($all_users ? '' : PMA_sqlAddslashes($fields['user'])) . '\', \'' . PMA_sqlAddslashes(urldecode($fields['query'])) . '\', \'' . PMA_sqlAddslashes($fields['label']) . '\')';
+    $result   = PMA_DBI_query($query, $controllink);
 
     return TRUE;
 } // end of the 'PMA_addBookmarks()' function
@@ -186,13 +190,13 @@ function PMA_addBookmarks($fields, $cfgBookmark, $all_users = false)
  */
 function PMA_deleteBookmarks($db, $cfgBookmark, $id)
 {
-    global $dbh;
+    global $controllink;
 
     $query  = 'DELETE FROM ' . PMA_backquote($cfgBookmark['db']) . '.' . PMA_backquote($cfgBookmark['table'])
             . ' WHERE (user = \'' . PMA_sqlAddslashes($cfgBookmark['user']) . '\''
             . '        OR user = \'\')'
             . ' AND id = ' . $id;
-    $result = PMA_DBI_try_query($query, $dbh);
+    $result = PMA_DBI_try_query($query, $controllink);
 } // end of the 'PMA_deleteBookmarks()' function
 
 
